@@ -134,7 +134,7 @@ ConfigDialog::ConfigDialog(TQWidget* parent_, const char* name_/*=0*/)
   enableButtonApply(false);
 
   setHelp(TQString::fromLatin1("general-options"));
-  connect(this, TQT_SIGNAL(aboutToShowPage(TQWidget*)), TQT_SLOT(slotUpdateHelpLink(TQWidget*)));
+  connect(this, TQ_SIGNAL(aboutToShowPage(TQWidget*)), TQ_SLOT(slotUpdateHelpLink(TQWidget*)));
 }
 
 ConfigDialog::~ConfigDialog() {
@@ -202,13 +202,13 @@ void ConfigDialog::setupGeneralPage() {
   TQWhatsThis::add(m_cbOpenLastFile, i18n("If checked, the file that was last open "
                                          "will be re-opened at program start-up."));
   l->addWidget(m_cbOpenLastFile);
-  connect(m_cbOpenLastFile, TQT_SIGNAL(clicked()), TQT_SLOT(slotModified()));
+  connect(m_cbOpenLastFile, TQ_SIGNAL(clicked()), TQ_SLOT(slotModified()));
 
   m_cbShowTipDay = new TQCheckBox(i18n("&Show \"Tip of the Day\" at startup"), frame);
   TQWhatsThis::add(m_cbShowTipDay, i18n("If checked, the \"Tip of the Day\" will be "
                                        "shown at program start-up."));
   l->addWidget(m_cbShowTipDay);
-  connect(m_cbShowTipDay, TQT_SIGNAL(clicked()), TQT_SLOT(slotModified()));
+  connect(m_cbShowTipDay, TQ_SIGNAL(clicked()), TQ_SLOT(slotModified()));
 
   TQButtonGroup* imageGroup = new TQVButtonGroup(i18n("Image Storage Options"), frame);
   m_rbImageInFile = new TQRadioButton(i18n("Store images in data file"), imageGroup);
@@ -219,7 +219,7 @@ void ConfigDialog::setupGeneralPage() {
                                    "application directory, or stored in a directory in the "
                                    "same location as the data file."));
   l->addWidget(imageGroup);
-  connect(imageGroup, TQT_SIGNAL(clicked(int)), TQT_SLOT(slotModified()));
+  connect(imageGroup, TQ_SIGNAL(clicked(int)), TQ_SLOT(slotModified()));
 
   TQVGroupBox* formatGroup = new TQVGroupBox(i18n("Formatting Options"), frame);
   l->addWidget(formatGroup);
@@ -227,12 +227,12 @@ void ConfigDialog::setupGeneralPage() {
   m_cbCapitalize = new TQCheckBox(i18n("Auto capitalize &titles and names"), formatGroup);
   TQWhatsThis::add(m_cbCapitalize, i18n("If checked, titles and names will "
                                        "be automatically capitalized."));
-  connect(m_cbCapitalize, TQT_SIGNAL(clicked()), TQT_SLOT(slotModified()));
+  connect(m_cbCapitalize, TQ_SIGNAL(clicked()), TQ_SLOT(slotModified()));
 
   m_cbFormat = new TQCheckBox(i18n("Auto &format titles and names"), formatGroup);
   TQWhatsThis::add(m_cbFormat, i18n("If checked, titles and names will "
                                    "be automatically formatted."));
-  connect(m_cbFormat, TQT_SIGNAL(clicked()), TQT_SLOT(slotModified()));
+  connect(m_cbFormat, TQ_SIGNAL(clicked()), TQ_SLOT(slotModified()));
 
   TQGrid* g1 = new TQGrid(2, formatGroup);
   g1->setSpacing(5);
@@ -244,7 +244,7 @@ void ConfigDialog::setupGeneralPage() {
                        "should be separated by a semi-colon.</qt>");
   TQWhatsThis::add(lab, whats);
   TQWhatsThis::add(m_leCapitals, whats);
-  connect(m_leCapitals, TQT_SIGNAL(textChanged(const TQString&)), TQT_SLOT(slotModified()));
+  connect(m_leCapitals, TQ_SIGNAL(textChanged(const TQString&)), TQ_SLOT(slotModified()));
 
   lab = new TQLabel(i18n("Artic&les:"), g1);
   m_leArticles = new KLineEdit(g1);
@@ -254,7 +254,7 @@ void ConfigDialog::setupGeneralPage() {
                "should be separated by a semi-colon.</qt>");
   TQWhatsThis::add(lab, whats);
   TQWhatsThis::add(m_leArticles, whats);
-  connect(m_leArticles, TQT_SIGNAL(textChanged(const TQString&)), TQT_SLOT(slotModified()));
+  connect(m_leArticles, TQ_SIGNAL(textChanged(const TQString&)), TQ_SLOT(slotModified()));
 
   lab = new TQLabel(i18n("Personal suffi&xes:"), g1);
   m_leSuffixes = new KLineEdit(g1);
@@ -263,7 +263,7 @@ void ConfigDialog::setupGeneralPage() {
                "should be separated by a semi-colon.</qt>");
   TQWhatsThis::add(lab, whats);
   TQWhatsThis::add(m_leSuffixes, whats);
-  connect(m_leSuffixes, TQT_SIGNAL(textChanged(const TQString&)), TQT_SLOT(slotModified()));
+  connect(m_leSuffixes, TQ_SIGNAL(textChanged(const TQString&)), TQ_SLOT(slotModified()));
 
   lab = new TQLabel(i18n("Surname &prefixes:"), g1);
   m_lePrefixes = new KLineEdit(g1);
@@ -272,7 +272,7 @@ void ConfigDialog::setupGeneralPage() {
                "should be separated by a semi-colon.</qt>");
   TQWhatsThis::add(lab, whats);
   TQWhatsThis::add(m_lePrefixes, whats);
-  connect(m_lePrefixes, TQT_SIGNAL(textChanged(const TQString&)), TQT_SLOT(slotModified()));
+  connect(m_lePrefixes, TQ_SIGNAL(textChanged(const TQString&)), TQ_SLOT(slotModified()));
 
   // stretch to fill lower area
   l->addStretch(1);
@@ -301,18 +301,18 @@ void ConfigDialog::setupPrintingPage() {
 
   m_cbPrintFormatted = new TQCheckBox(i18n("&Format titles and names"), formatOptions);
   TQWhatsThis::add(m_cbPrintFormatted, i18n("If checked, titles and names will be automatically formatted."));
-  connect(m_cbPrintFormatted, TQT_SIGNAL(clicked()), TQT_SLOT(slotModified()));
+  connect(m_cbPrintFormatted, TQ_SIGNAL(clicked()), TQ_SLOT(slotModified()));
 
   m_cbPrintHeaders = new TQCheckBox(i18n("&Print field headers"), formatOptions);
   TQWhatsThis::add(m_cbPrintHeaders, i18n("If checked, the field names will be printed as table headers."));
-  connect(m_cbPrintHeaders, TQT_SIGNAL(clicked()), TQT_SLOT(slotModified()));
+  connect(m_cbPrintHeaders, TQ_SIGNAL(clicked()), TQ_SLOT(slotModified()));
 
   TQHGroupBox* groupOptions = new TQHGroupBox(i18n("Grouping Options"), frame);
   l->addWidget(groupOptions);
 
   m_cbPrintGrouped = new TQCheckBox(i18n("&Group the entries"), groupOptions);
   TQWhatsThis::add(m_cbPrintGrouped, i18n("If checked, the entries will be grouped by the selected field."));
-  connect(m_cbPrintGrouped, TQT_SIGNAL(clicked()), TQT_SLOT(slotModified()));
+  connect(m_cbPrintGrouped, TQ_SIGNAL(clicked()), TQ_SLOT(slotModified()));
 
   TQVGroupBox* imageOptions = new TQVGroupBox(i18n("Image Options"), frame);
   l->addWidget(imageOptions);
@@ -328,10 +328,10 @@ void ConfigDialog::setupPrintingPage() {
   TQString whats = i18n("The maximum width of the images in the printout. The aspect ration is preserved.");
   TQWhatsThis::add(lab, whats);
   TQWhatsThis::add(m_imageWidthBox, whats);
-  connect(m_imageWidthBox, TQT_SIGNAL(valueChanged(int)), TQT_SLOT(slotModified()));
+  connect(m_imageWidthBox, TQ_SIGNAL(valueChanged(int)), TQ_SLOT(slotModified()));
   // TQSpinBox doesn't emit valueChanged if you edit the value with
   // the lineEdit until you change the keyboard focus
-  connect(m_imageWidthBox->child("qt_spinbox_edit"), TQT_SIGNAL(textChanged(const TQString&)), TQT_SLOT(slotModified()));
+  connect(m_imageWidthBox->child("qt_spinbox_edit"), TQ_SIGNAL(textChanged(const TQString&)), TQ_SLOT(slotModified()));
 
   lab = new TQLabel(i18n("&Maximum image height:"), grid);
   m_imageHeightBox = new KIntSpinBox(0, 999, 1, 50, 10, grid);
@@ -341,10 +341,10 @@ void ConfigDialog::setupPrintingPage() {
   whats = i18n("The maximum height of the images in the printout. The aspect ration is preserved.");
   TQWhatsThis::add(lab, whats);
   TQWhatsThis::add(m_imageHeightBox, whats);
-  connect(m_imageHeightBox, TQT_SIGNAL(valueChanged(int)), TQT_SLOT(slotModified()));
+  connect(m_imageHeightBox, TQ_SIGNAL(valueChanged(int)), TQ_SLOT(slotModified()));
   // TQSpinBox doesn't emit valueChanged if you edit the value with
   // the lineEdit until you change the keyboard focus
-  connect(m_imageHeightBox->child("qt_spinbox_edit"), TQT_SIGNAL(textChanged(const TQString&)), TQT_SLOT(slotModified()));
+  connect(m_imageHeightBox->child("qt_spinbox_edit"), TQ_SIGNAL(textChanged(const TQString&)), TQ_SLOT(slotModified()));
 
   // stretch to fill lower area
   l->addStretch(1);
@@ -368,7 +368,7 @@ void ConfigDialog::setupTemplatePage() {
 
   lab = new TQLabel(i18n("Template:"), frame);
   m_templateCombo = new GUI::ComboBox(frame);
-  connect(m_templateCombo, TQT_SIGNAL(activated(int)), TQT_SLOT(slotModified()));
+  connect(m_templateCombo, TQ_SIGNAL(activated(int)), TQ_SLOT(slotModified()));
   lab->setBuddy(m_templateCombo);
   TQString whats = i18n("Select the template to use for the current type of collections. "
                        "Not all templates will use the font and color settings.");
@@ -381,7 +381,7 @@ void ConfigDialog::setupTemplatePage() {
   TQWhatsThis::add(btn, i18n("Show a preview of the template"));
   btn->setIconSet(SmallIconSet(TQString::fromLatin1("viewmag")));
   gridLayout->addWidget(btn, row, 2);
-  connect(btn, TQT_SIGNAL(clicked()), TQT_SLOT(slotShowTemplatePreview()));
+  connect(btn, TQ_SIGNAL(clicked()), TQ_SLOT(slotShowTemplatePreview()));
 
   // so the button is squeezed small
   gridLayout->setColStretch(0, 10);
@@ -395,7 +395,7 @@ void ConfigDialog::setupTemplatePage() {
 //  l1->setTextFormat(TQt::RichText);
 //  l->addWidget(l1);
 
-  TQGroupBox* fontGroup = new TQGroupBox(0, Qt::Vertical, i18n("Font Options"), frame);
+  TQGroupBox* fontGroup = new TQGroupBox(0, TQt::Vertical, i18n("Font Options"), frame);
   l->addWidget(fontGroup);
 
   row = -1;
@@ -406,7 +406,7 @@ void ConfigDialog::setupTemplatePage() {
   fontLayout->addWidget(lab, ++row, 0);
   m_fontCombo = new TDEFontCombo(fontGroup);
   fontLayout->addWidget(m_fontCombo, row, 1);
-  connect(m_fontCombo, TQT_SIGNAL(activated(int)), TQT_SLOT(slotModified()));
+  connect(m_fontCombo, TQ_SIGNAL(activated(int)), TQ_SLOT(slotModified()));
   lab->setBuddy(m_fontCombo);
   whats = i18n("This font is passed to the template used in the Entry View.");
   TQWhatsThis::add(lab, whats);
@@ -417,12 +417,12 @@ void ConfigDialog::setupTemplatePage() {
   m_fontSizeInput->setRange(5, 30); // 30 is same max as konq config
   m_fontSizeInput->setSuffix(TQString::fromLatin1("pt"));
   fontLayout->addWidget(m_fontSizeInput, row, 1);
-  connect(m_fontSizeInput, TQT_SIGNAL(valueChanged(int)), TQT_SLOT(slotModified()));
+  connect(m_fontSizeInput, TQ_SIGNAL(valueChanged(int)), TQ_SLOT(slotModified()));
   lab->setBuddy(m_fontSizeInput);
   TQWhatsThis::add(lab, whats);
   TQWhatsThis::add(m_fontSizeInput, whats);
 
-  TQGroupBox* colGroup = new TQGroupBox(0, Qt::Vertical, i18n("Color Options"), frame);
+  TQGroupBox* colGroup = new TQGroupBox(0, TQt::Vertical, i18n("Color Options"), frame);
   l->addWidget(colGroup);
 
   row = -1;
@@ -433,7 +433,7 @@ void ConfigDialog::setupTemplatePage() {
   colLayout->addWidget(lab, ++row, 0);
   m_baseColorCombo = new KColorCombo(colGroup);
   colLayout->addWidget(m_baseColorCombo, row, 1);
-  connect(m_baseColorCombo, TQT_SIGNAL(activated(int)), TQT_SLOT(slotModified()));
+  connect(m_baseColorCombo, TQ_SIGNAL(activated(int)), TQ_SLOT(slotModified()));
   lab->setBuddy(m_baseColorCombo);
   whats = i18n("This color is passed to the template used in the Entry View.");
   TQWhatsThis::add(lab, whats);
@@ -443,7 +443,7 @@ void ConfigDialog::setupTemplatePage() {
   colLayout->addWidget(lab, ++row, 0);
   m_textColorCombo = new KColorCombo(colGroup);
   colLayout->addWidget(m_textColorCombo, row, 1);
-  connect(m_textColorCombo, TQT_SIGNAL(activated(int)), TQT_SLOT(slotModified()));
+  connect(m_textColorCombo, TQ_SIGNAL(activated(int)), TQ_SLOT(slotModified()));
   lab->setBuddy(m_textColorCombo);
   TQWhatsThis::add(lab, whats);
   TQWhatsThis::add(m_textColorCombo, whats);
@@ -452,7 +452,7 @@ void ConfigDialog::setupTemplatePage() {
   colLayout->addWidget(lab, ++row, 0);
   m_highBaseColorCombo = new KColorCombo(colGroup);
   colLayout->addWidget(m_highBaseColorCombo, row, 1);
-  connect(m_highBaseColorCombo, TQT_SIGNAL(activated(int)), TQT_SLOT(slotModified()));
+  connect(m_highBaseColorCombo, TQ_SIGNAL(activated(int)), TQ_SLOT(slotModified()));
   lab->setBuddy(m_highBaseColorCombo);
   TQWhatsThis::add(lab, whats);
   TQWhatsThis::add(m_highBaseColorCombo, whats);
@@ -461,7 +461,7 @@ void ConfigDialog::setupTemplatePage() {
   colLayout->addWidget(lab, ++row, 0);
   m_highTextColorCombo = new KColorCombo(colGroup);
   colLayout->addWidget(m_highTextColorCombo, row, 1);
-  connect(m_highTextColorCombo, TQT_SIGNAL(activated(int)), TQT_SLOT(slotModified()));
+  connect(m_highTextColorCombo, TQ_SIGNAL(activated(int)), TQ_SLOT(slotModified()));
   lab->setBuddy(m_highTextColorCombo);
   TQWhatsThis::add(lab, whats);
   TQWhatsThis::add(m_highTextColorCombo, whats);
@@ -474,19 +474,19 @@ void ConfigDialog::setupTemplatePage() {
 
   KPushButton* b1 = new KPushButton(i18n("Install..."), box1);
   b1->setIconSet(SmallIconSet(TQString::fromLatin1("add")));
-  connect(b1, TQT_SIGNAL(clicked()), TQT_SLOT(slotInstallTemplate()));
+  connect(b1, TQ_SIGNAL(clicked()), TQ_SLOT(slotInstallTemplate()));
   whats = i18n("Click to install a new template directly.");
   TQWhatsThis::add(b1, whats);
 
   KPushButton* b2 = new KPushButton(i18n("Download..."), box1);
   b2->setIconSet(SmallIconSet(TQString::fromLatin1("knewstuff")));
-  connect(b2, TQT_SIGNAL(clicked()), TQT_SLOT(slotDownloadTemplate()));
+  connect(b2, TQ_SIGNAL(clicked()), TQ_SLOT(slotDownloadTemplate()));
   whats = i18n("Click to download additional templates via the Internet.");
   TQWhatsThis::add(b2, whats);
 
   KPushButton* b3 = new KPushButton(i18n("Delete..."), box1);
   b3->setIconSet(SmallIconSet(TQString::fromLatin1("remove")));
-  connect(b3, TQT_SIGNAL(clicked()), TQT_SLOT(slotDeleteTemplate()));
+  connect(b3, TQ_SIGNAL(clicked()), TQ_SLOT(slotDeleteTemplate()));
   whats = i18n("Click to select and remove installed templates.");
   TQWhatsThis::add(b3, whats);
 
@@ -508,8 +508,8 @@ void ConfigDialog::setupFetchPage() {
   m_sourceListView->setSorting(-1); // no sorting
   m_sourceListView->setSelectionMode(TQListView::Single);
   leftLayout->addWidget(m_sourceListView, 1);
-  connect(m_sourceListView, TQT_SIGNAL(selectionChanged(TQListViewItem*)), TQT_SLOT(slotSelectedSourceChanged(TQListViewItem*)));
-  connect(m_sourceListView, TQT_SIGNAL(doubleClicked(TQListViewItem*, const TQPoint&, int)), TQT_SLOT(slotModifySourceClicked()));
+  connect(m_sourceListView, TQ_SIGNAL(selectionChanged(TQListViewItem*)), TQ_SLOT(slotSelectedSourceChanged(TQListViewItem*)));
+  connect(m_sourceListView, TQ_SIGNAL(doubleClicked(TQListViewItem*, const TQPoint&, int)), TQ_SLOT(slotModifySourceClicked()));
 
   TQHBox* hb = new TQHBox(frame);
   leftLayout->addWidget(hb);
@@ -551,12 +551,12 @@ void ConfigDialog::setupFetchPage() {
   vlay->addWidget(m_newStuffBtn);
   vlay->addStretch(1);
 
-  connect(newSourceBtn, TQT_SIGNAL(clicked()), TQT_SLOT(slotNewSourceClicked()));
-  connect(m_modifySourceBtn, TQT_SIGNAL(clicked()), TQT_SLOT(slotModifySourceClicked()));
-  connect(m_moveUpSourceBtn, TQT_SIGNAL(clicked()), TQT_SLOT(slotMoveUpSourceClicked()));
-  connect(m_moveDownSourceBtn, TQT_SIGNAL(clicked()), TQT_SLOT(slotMoveDownSourceClicked()));
-  connect(m_removeSourceBtn, TQT_SIGNAL(clicked()), TQT_SLOT(slotRemoveSourceClicked()));
-  connect(m_newStuffBtn, TQT_SIGNAL(clicked()), TQT_SLOT(slotNewStuffClicked()));
+  connect(newSourceBtn, TQ_SIGNAL(clicked()), TQ_SLOT(slotNewSourceClicked()));
+  connect(m_modifySourceBtn, TQ_SIGNAL(clicked()), TQ_SLOT(slotModifySourceClicked()));
+  connect(m_moveUpSourceBtn, TQ_SIGNAL(clicked()), TQ_SLOT(slotMoveUpSourceClicked()));
+  connect(m_moveDownSourceBtn, TQ_SIGNAL(clicked()), TQ_SLOT(slotMoveDownSourceClicked()));
+  connect(m_removeSourceBtn, TQ_SIGNAL(clicked()), TQ_SLOT(slotRemoveSourceClicked()));
+  connect(m_newStuffBtn, TQ_SIGNAL(clicked()), TQ_SLOT(slotNewStuffClicked()));
 
   TDEAcceleratorManager::manage(frame);
 }
@@ -1021,7 +1021,7 @@ void ConfigDialog::slotInstallTemplate() {
     return;
   }
 
-  NewStuff::Manager man(TQT_TQOBJECT(this));
+  NewStuff::Manager man(this);
   if(man.installTemplate(u)) {
     loadTemplateList();
   }
@@ -1051,7 +1051,7 @@ void ConfigDialog::slotDeleteTemplate() {
                                        nameFileMap.keys(), 0, false, &ok, this);
   if(ok && !name.isEmpty()) {
     TQString file = nameFileMap[name];
-    NewStuff::Manager man(TQT_TQOBJECT(this));
+    NewStuff::Manager man(this);
     man.removeTemplate(file);
     loadTemplateList();
   }
