@@ -128,10 +128,10 @@ void DiscogsFetcher::doSearch() {
 //  myDebug() << "DiscogsFetcher::search() - url: " << u.url() << endl;
 
   m_job = TDEIO::get(u, false, false);
-  connect(m_job, TQT_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
-          TQT_SLOT(slotData(TDEIO::Job*, const TQByteArray&)));
-  connect(m_job, TQT_SIGNAL(result(TDEIO::Job*)),
-          TQT_SLOT(slotComplete(TDEIO::Job*)));
+  connect(m_job, TQ_SIGNAL(data(TDEIO::Job*, const TQByteArray&)),
+          TQ_SLOT(slotData(TDEIO::Job*, const TQByteArray&)));
+  connect(m_job, TQ_SIGNAL(result(TDEIO::Job*)),
+          TQ_SLOT(slotComplete(TDEIO::Job*)));
 }
 
 void DiscogsFetcher::stop() {
@@ -357,7 +357,7 @@ DiscogsFetcher::ConfigWidget::ConfigWidget(TQWidget* parent_, const DiscogsFetch
   l->addWidget(label, ++row, 0);
 
   m_apiKeyEdit = new KLineEdit(optionsWidget());
-  connect(m_apiKeyEdit, TQT_SIGNAL(textChanged(const TQString&)), TQT_SLOT(slotSetModified()));
+  connect(m_apiKeyEdit, TQ_SIGNAL(textChanged(const TQString&)), TQ_SLOT(slotSetModified()));
   l->addWidget(m_apiKeyEdit, row, 1);
   TQString w = i18n("With your discogs.com account you receive an API key for the usage of their XML-based interface "
                    "(See http://www.discogs.com/help/api).");
@@ -366,7 +366,7 @@ DiscogsFetcher::ConfigWidget::ConfigWidget(TQWidget* parent_, const DiscogsFetch
   label->setBuddy(m_apiKeyEdit);
 
   m_fetchImageCheck = new TQCheckBox(i18n("Download cover &image"), optionsWidget());
-  connect(m_fetchImageCheck, TQT_SIGNAL(clicked()), TQT_SLOT(slotSetModified()));
+  connect(m_fetchImageCheck, TQ_SIGNAL(clicked()), TQ_SLOT(slotSetModified()));
   ++row;
   l->addMultiCellWidget(m_fetchImageCheck, row, row, 0, 1);
   w = i18n("The cover image may be downloaded as well. However, too many large images in the "
