@@ -47,7 +47,7 @@ class SRUConfigWidget;
  * @author Robby Stephenson
  */
 class SRUFetcher : public Fetcher {
-Q_OBJECT
+TQ_OBJECT
   
 
 friend class SRUConfigWidget;
@@ -108,7 +108,7 @@ private:
 };
 
 class SRUConfigWidget : public ConfigWidget {
-Q_OBJECT
+TQ_OBJECT
   
 
 friend class SRUFetcher;
