@@ -66,13 +66,13 @@ DateWidget::DateWidget(TQWidget* parent_, const char* name_) : TQWidget(parent_,
                            locale->calendar()->maxValidYear(), this);
   l->addWidget(m_yearSpin, 1);
 
-  connect(m_daySpin, TQT_SIGNAL(valueChanged(int)), TQT_SLOT(slotDateChanged()));
-  connect(m_monthCombo, TQT_SIGNAL(activated(int)), TQT_SLOT(slotDateChanged()));
-  connect(m_yearSpin, TQT_SIGNAL(valueChanged(int)), TQT_SLOT(slotDateChanged()));
+  connect(m_daySpin, TQ_SIGNAL(valueChanged(int)), TQ_SLOT(slotDateChanged()));
+  connect(m_monthCombo, TQ_SIGNAL(activated(int)), TQ_SLOT(slotDateChanged()));
+  connect(m_yearSpin, TQ_SIGNAL(valueChanged(int)), TQ_SLOT(slotDateChanged()));
 
   m_dateButton = new KPushButton(this);
   m_dateButton->setIconSet(SmallIconSet(TQString::fromLatin1("date")));
-  connect(m_dateButton, TQT_SIGNAL(clicked()), TQT_SLOT(slotShowPicker()));
+  connect(m_dateButton, TQ_SIGNAL(clicked()), TQ_SLOT(slotShowPicker()));
   l->addWidget(m_dateButton, 0);
 
   m_frame = new TQVBox(0, 0, WType_Popup);
@@ -81,8 +81,8 @@ DateWidget::DateWidget(TQWidget* parent_, const char* name_) : TQWidget(parent_,
   m_frame->hide();
 
   m_picker = new KDatePicker(m_frame, 0); // must include name to get correct constructor
-  connect(m_picker, TQT_SIGNAL(dateEntered(TQDate)), TQT_SLOT(slotDateEntered(TQDate)));
-  connect(m_picker, TQT_SIGNAL(dateSelected(TQDate)), TQT_SLOT(slotDateSelected(TQDate)));
+  connect(m_picker, TQ_SIGNAL(dateEntered(TQDate)), TQ_SLOT(slotDateEntered(TQDate)));
+  connect(m_picker, TQ_SIGNAL(dateSelected(TQDate)), TQ_SLOT(slotDateSelected(TQDate)));
 }
 
 void DateWidget::slotDateChanged() {
