@@ -1,4 +1,4 @@
-/*  -*- c++ -*-
+/*
     kwidgetlister.cpp
 
     This file is part of libtdenetwork.
@@ -71,12 +71,12 @@ KWidgetLister::KWidgetLister( int minWidgets, int maxWidgets, TQWidget *parent,
   mButtonBox->setStretchFactor( mBtnClear, 0 );
 
   //---------- connect everything
-  connect( mBtnMore, TQT_SIGNAL(clicked()),
-     this, TQT_SLOT(slotMore()) );
-  connect( mBtnFewer, TQT_SIGNAL(clicked()),
-     this, TQT_SLOT(slotFewer()) );
-  connect( mBtnClear, TQT_SIGNAL(clicked()),
-     this, TQT_SLOT(slotClear()) );
+  connect( mBtnMore, TQ_SIGNAL(clicked()),
+     this, TQ_SLOT(slotMore()) );
+  connect( mBtnFewer, TQ_SIGNAL(clicked()),
+     this, TQ_SLOT(slotFewer()) );
+  connect( mBtnClear, TQ_SIGNAL(clicked()),
+     this, TQ_SLOT(slotClear()) );
 
   enableControls();
 }
