@@ -26,7 +26,7 @@ namespace Tellico {
  *@author Robby Stephenson
  */
 class BibtexmlImporter : public XMLImporter {
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
