@@ -39,7 +39,7 @@ namespace Tellico {
  * @author Robby Stephenson
  */
 class CSVImporter : public TextImporter {
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
