@@ -26,7 +26,7 @@ namespace Tellico {
  * @author Robby Stephenson
 */
 class GCfilmsImporter : public TextImporter {
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
