@@ -20,7 +20,7 @@ namespace Tellico {
   namespace Import {
 
 class PDFImporter : public Importer {
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
